MOEXAlgo
========
🚀 MoexAlgo предоставляет данные и аналитику по рынку акций, фьючерсов и валют Московской Биржи (MOEX).

Более 100 уникальных метрик! С помощью ALGOPACK можно получать:

- **Исторические данные** - для тестирования торговых стратегий, проверки гипотез и бэктестов
- **Онлайн данные** - для алгоритмической торговли


Установка библиотеки
--------------------
Перед началом использования библиотеку следует установить из PyPI:

.. code:: bash

    pip install moexalgo

Если вы планируете использовать библиотеку в Jupyter Notebook,
то следует установить сразу с необходимыми для этого зависимостями:

.. code:: bash

    pip install moexalgo[dataframe]

Исходный код доступен в `репозитории GitHub <https://github.com/moexalgo/moexalgo>`_.


API
---

.. toctree::
   :maxdepth: 1

   auth
   market
   ticker

Пример использования
--------------------
В репозитории исходного кода, в каталоге `samples` вы найдете примеры использования
библиотеки, такие как:

 - ⚡️ Быстрое знакомство с библиотекой MoexAlgo - `samples/quick_start.ipynb`
 - ⬇️ Получение данных через API - `samples/download_algopack_data.ipynb`
 - 🔐 Пример авторизации - `/samples/auth.ipynb`
 - ⬇️ Получение данных c использованием APIКЕУ - `/samples/token.ipynb`


Устаревшее!
-----------
Именованный аргумент `use_dataframe` исключен из параметров запроса.
Теперь библиотека определяет, в какой среде она будет использоваться. В Jupyter Notebook результат
возвращается как `pd.Dataftame`, в обычной среде - как `Iterator[dict[str, Any]]`.
Однако, если вам необходимо получить результат в Jupyter Notebook без преобразования в dataframe,
используйте именованный аргумент `native=True'.